@@ -138,35 +138,10 @@ make them more smooth.</source>
 </context>
 <context>
     <name>ApplicationSettings</name>
-    <message>
-        <source>Always copy capture to clipboard</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Prompt to save before discarding unsaved changes</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Save ksnip position on move and load on startup</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Save ksnip tool selection and load on startup</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Capture screenshot at startup with default mode</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Instant save to default location without &apos;Save as&apos; dialog</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>When enabled, will not ask where to save a screenshot
-when saving, but will save instantly to default location.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Use Tray Icon</source>
         <translation type="unfinished"></translation>
@@ -180,10 +155,6 @@ Change requires restart.</source>
         <source>Minimize to Tray</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Start Minimized to Tray.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Close to Tray</source>
         <translation type="unfinished"></translation>
@@ -197,24 +168,51 @@ Change requires restart.</source>
 Change requires ksnip restart to take effect.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Capture save location and filename</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Filename can contain $Y, $M, $D for date, $h, $m, $s for time, or $T for time in hhmmss format.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Browse</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Application Settings</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Capture save location</source>
+        <source>Automatically copy new captures to clipboard</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto Hide Tabs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hide Tabbar when only on Tab is used.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remember ksnip position on move and load on startup</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remember ksnip tool selection and load on startup</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use Tabs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Change requires restart.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Run ksnip as single instance</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enabling this option will allow only one ksnip instance to run,
+all other instances started after the first will pass it&apos;s
+arguments to the first and close. Changing this option requires
+a new start of all instances.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start Minimized to Tray</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -260,7 +258,7 @@ Change requires ksnip restart to take effect.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>The capture has been modified.
+        <source>The capture %1%2%3 has been modified.
 Do you want to save it?</source>
         <translation type="unfinished"></translation>
     </message>
@@ -320,21 +318,6 @@ Do you want to save it?</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>CaptureUploader</name>
-    <message>
-        <source>Upload to imgur.com finished!</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Received new token, trying upload again…</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Imgur token has expired, requesting new token…</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>DonateTab</name>
     <message>
@@ -363,15 +346,59 @@ Do you want to save it?</source>
     </message>
 </context>
 <context>
-    <name>HandleUploadResponseOperation</name>
+    <name>HandleUploadResultOperation</name>
     <message>
         <source>Upload Successful</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Upload script </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source> finished successfully.</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Uploaded to</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Unable to save temporary image for upload.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to start process, check path and permissions.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Process crashed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Process timed out.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Process read error.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Process write error.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Web error, check console output.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown process error.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Upload Failed</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>HotKeySettings</name>
@@ -411,6 +438,10 @@ Do you want to save it?</source>
         <source>Global HotKeys</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Clear</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ImageGrabberSettings</name>
@@ -501,7 +532,7 @@ take effect.</source>
     </message>
     <message>
         <source>Close</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Luk</translation>
     </message>
     <message>
         <source>Time Stamp</source>
@@ -516,6 +547,21 @@ take effect.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>ImgurUploader</name>
+    <message>
+        <source>Upload to imgur.com finished!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Received new token, trying upload again…</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Imgur token has expired, requesting new token…</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>ImgurUploaderSettings</name>
     <message>
@@ -534,10 +580,6 @@ take effect.</source>
         <source>Always copy Imgur link to clipboard</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Ask for confirmation before uploading</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Client ID</source>
         <translation type="unfinished"></translation>
@@ -590,6 +632,15 @@ take effect.</source>
         <source>Imgur.com token update error.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Base Url:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Base url that will be used for communication with Imgur.
+Changing requires restart.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainToolBar</name>
@@ -661,10 +712,6 @@ and capturing screenshot.</source>
         <source>Upload</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Upload capture image to imgur.com</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Print</source>
         <translation type="unfinished"></translation>
@@ -737,6 +784,29 @@ and capturing screenshot.</source>
         <source>Image Files (*.png *.jpg *.bmp)</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Save As...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Paste</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Paste Embedded</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Upload capture to external source</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>NewCaptureNameProvider</name>
+    <message>
+        <source>Capture</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SaveOperation</name>
@@ -769,6 +839,95 @@ and capturing screenshot.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>SaverSettings</name>
+    <message>
+        <source>Automatically save new captures to default location</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Prompt to save before discarding unsaved changes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remember last Save Directory</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>When enabled will overwrite the save directory stored in settings
+with the latest save directory, for every save.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Capture save location and filename</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Supported Formats are JPG, PNG and BMP. If no format provided, PNG will be used as default.
+Filename can contain following wildcards:
+- $Y, $M, $D for date, $h, $m, $s for time, or $T for time in hhmmss format.
+- Multiple consecutive # for counter. #### will result in 0001, next capture would be 0002.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Browse</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Saver Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Capture save location</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ScriptUploaderSettings</name>
+    <message>
+        <source>Copy script output to clipboard</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>After:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Only output following this string will be copied to clipboard, excluding that string.
+If omitted, everything from start will be copied.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Before:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Only output before this string will be copied to clipboard, excluding that string.
+If omitted, everything up to the end will be copied.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Script:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Path to script that will be called for uploading. During upload the script will be called
+with the path to a temporary png file as a single argument.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Browse</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Script Uploader</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select Upload Script</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>SettingsDialog</name>
     <message>
@@ -803,6 +962,57 @@ and capturing screenshot.</source>
         <source>HotKeys</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Uploader</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Script Uploader</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Saver</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Stickers</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>StickerSettings</name>
+    <message>
+        <source>Up</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Down</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use Default Stickers</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sticker Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add Sticker</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Vector Image Files (*.svg)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>TrayIcon</name>
@@ -829,11 +1039,42 @@ and capturing screenshot.</source>
 <context>
     <name>UploadOperation</name>
     <message>
-        <source>Imgur Upload</source>
+        <source>Upload Script Required</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>You are about to upload the screenshot to a imgur.com, do you want to proceed?</source>
+        <source>Please add an upload script via Options &gt; Settings &gt; Upload Script</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Capture Upload</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You are about to upload the image to an external destination, do you want to proceed?</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>UploaderSettings</name>
+    <message>
+        <source>Ask for confirmation before uploading</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Uploader Type:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Imgur</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Script</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Uploader</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -841,7 +1082,7 @@ and capturing screenshot.</source>
     <name>VersionTab</name>
     <message>
         <source>Version</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Version</translation>
     </message>
     <message>
         <source>Build</source>
